@@ -4,7 +4,7 @@
  * This file is part of mpop, a POP3 client.
  *
  * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
- * 2012, 2013
+ * 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  * Dimitrios Apostolou <jimis@gmx.net> (UID handling)
  * Jay Soffian <jaysoffian@gmail.com> (Mac OS X keychain support)
@@ -1731,7 +1731,7 @@ int main(int argc, char *argv[])
             LONGONLYOPT_RECEIVED_HEADER },
         { "auth",                  optional_argument, 0, LONGONLYOPT_AUTH },
         { "user",                  required_argument, 0, LONGONLYOPT_USER },
-        { "passwordeval",          optional_argument, 0,
+        { "passwordeval",          required_argument, 0,
             LONGONLYOPT_PASSWORDEVAL },
         { "tls",                   optional_argument, 0, LONGONLYOPT_TLS },
         { "tls-starttls",          optional_argument, 0,
@@ -2348,7 +2348,7 @@ int main(int argc, char *argv[])
 # endif
 #endif
         printf("\n\n");
-        printf(_("Copyright (C) 2013 Martin Lambers and others.\n"
+        printf(_("Copyright (C) 2014 Martin Lambers and others.\n"
                     "This is free software.  You may redistribute copies of "
                         "it under the terms of\n"
                     "the GNU General Public License "
